@@ -26,37 +26,37 @@ describe('interpolateName()', () => {
       '/app/js/javascript.js',
       'js/[hash].script.[ext]',
       'test content',
-      'js/9473fdd0d880a43c21b7778d34872157.script.js',
+      'js/a69899814931280e2f527219ad6ac754.script.js',
     ],
     [
       '/app/js/javascript.js',
       'js/[contenthash].script.[ext]',
       'test content',
-      'js/9473fdd0d880a43c21b7778d34872157.script.js',
+      'js/a69899814931280e2f527219ad6ac754.script.js',
     ],
     [
       '/app/page.html',
       'html-[hash:6].html',
       'test content',
-      'html-9473fd.html',
+      'html-a69899.html',
     ],
     [
       '/app/page.html',
       'html-[contenthash:6].html',
       'test content',
-      'html-9473fd.html',
+      'html-a69899.html',
     ],
     [
       '/app/flash.txt',
       '[hash]',
       'test content',
-      '9473fdd0d880a43c21b7778d34872157',
+      'a69899814931280e2f527219ad6ac754',
     ],
     [
       '/app/flash.txt',
       '[contenthash]',
       'test content',
-      '9473fdd0d880a43c21b7778d34872157',
+      'a69899814931280e2f527219ad6ac754',
     ],
     [
       '/app/img/image.png',
@@ -74,13 +74,13 @@ describe('interpolateName()', () => {
       '/app/dir/file.png',
       '[path][name].[ext]?[hash]',
       'test content',
-      '/app/dir/file.png?9473fdd0d880a43c21b7778d34872157',
+      '/app/dir/file.png?a69899814931280e2f527219ad6ac754',
     ],
     [
       '/app/dir/file.png',
       '[path][name].[ext]?[contenthash]',
       'test content',
-      '/app/dir/file.png?9473fdd0d880a43c21b7778d34872157',
+      '/app/dir/file.png?a69899814931280e2f527219ad6ac754',
     ],
     [
       '/vendor/test/images/loading.gif',
@@ -131,10 +131,102 @@ describe('interpolateName()', () => {
       'test content',
       'modal.[md5::base64:20].css',
     ],
+    [
+      '/app/js/javascript.js?foo=bar',
+      'js/[hash].script.[ext][query]',
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js?foo=bar',
+    ],
+    [
+      '/app/js/javascript.js?foo=bar&bar=baz',
+      'js/[hash].script.[ext][query]',
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js?foo=bar&bar=baz',
+    ],
+    [
+      '/app/js/javascript.js?foo',
+      'js/[hash].script.[ext][query]',
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js?foo',
+    ],
+    [
+      '/app/js/javascript.js?',
+      'js/[hash].script.[ext][query]',
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js',
+    ],
+    [
+      '/app/js/javascript.js?a',
+      'js/[hash].script.[ext][query]',
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js?a',
+    ],
+    [
+      '/app/js/javascript.js?foo=bar#hash',
+      'js/[hash].script.[ext][query]',
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js?foo=bar',
+    ],
+    [
+      '/app/js/javascript.js?foo=bar#hash',
+      (resourcePath, resourceQuery) => {
+        expect(resourcePath).toBeDefined();
+        expect(resourceQuery).toBeDefined();
+
+        return 'js/[hash].script.[ext][query]';
+      },
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js?foo=bar',
+    ],
+    [
+      '/app/js/javascript.js?a',
+      (resourcePath, resourceQuery) => {
+        expect(resourcePath).toBeDefined();
+        expect(resourceQuery).toBeDefined();
+
+        return 'js/[hash].script.[ext][query]';
+      },
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js?a',
+    ],
+    [
+      '/app/js/javascript.js',
+      (resourcePath, resourceQuery) => {
+        expect(resourcePath).toBeDefined();
+        expect(resourceQuery).not.toBeDefined();
+
+        return 'js/[hash].script.[ext][query]';
+      },
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js',
+    ],
+    [
+      '/app/js/javascript.js?',
+      (resourcePath, resourceQuery) => {
+        expect(resourcePath).toBeDefined();
+        expect(resourceQuery).not.toBeDefined();
+
+        return 'js/[hash].script.[ext][query]';
+      },
+      'test content',
+      'js/a69899814931280e2f527219ad6ac754.script.js',
+    ],
   ].forEach((test) => {
     it('should interpolate ' + test[0] + ' ' + test[1], () => {
+      let resourcePath = '';
+      let resourceQuery = '';
+
+      const queryIdx = test[0].indexOf('?');
+
+      if (queryIdx >= 0) {
+        resourcePath = test[0].substr(0, queryIdx);
+        resourceQuery = test[0].substr(queryIdx);
+      } else {
+        resourcePath = test[0];
+      }
+
       const interpolatedName = loaderUtils.interpolateName(
-        { resourcePath: test[0] },
+        { resourcePath, resourceQuery },
         test[1],
         { content: test[2] }
       );
@@ -168,12 +260,12 @@ describe('interpolateName()', () => {
   run([
     [
       [{}, '', { content: 'test string' }],
-      '6f8db599de986fab7a21625b7916589c.bin',
+      '2e06edd4f1623268c5a51730d8a0b2af.bin',
       'should interpolate default tokens',
     ],
     [
       [{}, '[hash:base64]', { content: 'test string' }],
-      '2sm1pVmS8xuGJLCdWpJoRL',
+      '2LIG3oc1uBNmwOoL7kXgoK',
       'should interpolate [hash] token with options',
     ],
     [
